MSound class

Constructors

MSound({required MSoundConfig config, required MSoundEngine engine})

Properties

config MSoundConfig
final
engine MSoundEngine
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
play(String name) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

load({required MSoundConfig config}) Future<MSound>